@@ -1,12 +1,10 @@
 #include "MainWindow.h"
 
 #include "LoginDialog.h"
-#include "DialCancelDlg.h"
 #include "DlgSelectContactNumber.h"
 #include "VMailDialog.h"
 
 #include "PhoneNumberValidator.h"
-#include "DialContext.h"
 
 #include <QDesktopServices>
 
@@ -94,9 +92,7 @@ void
 MainWindow::initLogging ()
 {
     // Initialize logging
-    QString strLogfile;
-#ifndef Q_OS_SYMBIAN
-    strLogfile = QDir::homePath ();
+    QString strLogfile = QDir::homePath ();
     QDir dirHome(strLogfile);
     if (!strLogfile.endsWith (QDir::separator ()))
     {
@@ -107,7 +103,6 @@ MainWindow::initLogging ()
         dirHome.mkdir (".qgvdial");
     }
     strLogfile += QDir::separator ();
-#endif
     strLogfile += "qgvdial.log";
     fLogfile.setFileName (strLogfile);
     fLogfile.open (QIODevice::WriteOnly | QIODevice::Append);
@@ -156,7 +151,7 @@ MainWindow::log (const QString &strText, int level /*= 10*/)
  *          until the next status is to be displayed.
  */
 void
-MainWindow::setStatus(const QString &strText, int timeout /* = 0*/)
+MainWindow::setStatus(const QString &strText, int timeout /* = 3000*/)
 {
     qDebug () << strText;
 
@@ -228,6 +223,22 @@ MainWindow::messageReceived (const QString &message)
     }
 }//MainWindow::messageReceived
 
+/** Invoked when the user clicks the hide button or long presses the top bar
+ * This function is supposed to hide the qgvdial main window. On all platforms
+ * except Symbian a simple hide() is sufficient. In Symbian, we need to do it
+ * differently.
+ */
+void
+MainWindow::onSigHide ()
+{
+#if defined(Q_OS_SYMBIAN)
+    //@@UV: Something meaningful
+    this->lower ();
+#else
+    this->hide ();
+#endif
+}//MainWindow::onSigHide
+
 /** Deferred initialization function
  * This function does all of the initialization that was originally in the
  * constructor. It was moved out of the constructor because it takes a long time
@@ -343,7 +354,7 @@ MainWindow::init ()
     QObject::connect (&actLogin, SIGNAL (triggered()),
                        this    , SLOT   (on_action_Login_triggered()));
     QObject::connect (&actDismiss, SIGNAL (triggered()),
-                       this      , SLOT   (close()));
+                       this      , SLOT   (hide ()));
     QObject::connect (&actRefresh, SIGNAL (triggered()),
                        this      , SLOT   (onRefresh()));
     QObject::connect (&actExit, SIGNAL (triggered()),
@@ -377,7 +388,8 @@ MainWindow::init ()
     }
     else
     {
-        setStatus ("No user credentials cached. Please login");
+        // Show this status for 60 seconds (or until the next status)
+        setStatus ("Please enter email and password", 60 * 1000);
 
         // Do this otherwise the QML behaves silly.
         QDeclarativeContext *ctx = this->rootContext();
@@ -431,8 +443,8 @@ MainWindow::initQML ()
                       this, SLOT   (onRefresh ()));
     QObject::connect (gObj, SIGNAL (sigRefreshAll ()),
                       this, SLOT   (onRefreshAll ()));
-    QObject::connect (gObj, SIGNAL (sigDismiss ()),
-                      this, SLOT   (close ()));
+    QObject::connect (gObj, SIGNAL (sigHide ()),
+                      this, SLOT   (onSigHide ()));
     QObject::connect (gObj, SIGNAL (sigQuit ()),
                       this, SLOT   (on_actionE_xit_triggered ()));
     QObject::connect (gObj, SIGNAL (sigLinkActivated (const QString &)),
@@ -1017,32 +1029,26 @@ MainWindow::dialNow (const QString &strTarget)
             break;
         }
 
-        DialContext *ctx = new DialContext(this);
+        DialContext *ctx = new DialContext(strSelfNumber, strTarget, this);
         if (NULL == ctx) {
             setStatus ("Failed to dial out because of allocation problem");
             break;
         }
+        QObject::connect (ctx , SIGNAL(sigDialComplete(DialContext*,bool)),
+                          this, SLOT(onSigDialComplete(DialContext*,bool)));
 
         GVAccess &webPage = Singletons::getRef().getGVAccess ();
         QVariantList l;
         l += strTarget;     // The destination number is common between the two
         l += QVariant::fromValue<void*>(ctx);
 
-        DialCancelDlg *pDialDlg = new DialCancelDlg (strTarget, ctx, this);
-        QObject::connect (
-            pDialDlg, SIGNAL (dialDlgDone    (int, const QString &, void *)),
-            this    , SLOT   (onDialDlgClose (int, const QString &, void *)));
-
         OsDependent &osd = Singletons::getRef().getOSD ();
         osd.setLongWork (this, true);
 
         bCallInProgress = true;
         bDialCancelled = false;
 
-        pDialDlg->setModal (false);
-        pDialDlg->doNonModal (strSelfNumber);
-
-        ctx->pDialDlg = pDialDlg;
+        ctx->showMsgBox ();
 
         if (bDialout)
         {
@@ -1067,7 +1073,7 @@ MainWindow::dialNow (const QString &strTarget)
             {
                 setStatus ("Dialing failed instantly");
                 bCallInProgress = bDialCancelled = false;
-                pDialDlg->deleteLater ();
+                ctx->deleteLater ();
                 break;
             }
         }
@@ -1137,24 +1143,20 @@ MainWindow::onSendTextWithoutData (const QStringList &arrNumbers)
 }//MainWindow::onSendTextWithoutData
 
 void
-MainWindow::onDialDlgClose (int retval,
-                            const QString & /*strNumber*/,
-                            void *pvctx)
+MainWindow::onSigDialComplete (DialContext *ctx, bool ok)
 {
-    DialContext *ctx = (DialContext *) pvctx;
     // Disconnecting this
     QMutexLocker locker (&mtxDial);
-    if (QMessageBox::Ok == retval)
-    {
-        emit dialCanFinish ();
-    }
-    else
-    {
+    if (ok) {
+        if (!ctx->bDialOut) {
+            emit dialCanFinish ();
+        }
+    } else {
         GVAccess &webPage = Singletons::getRef().getGVAccess ();
         bDialCancelled = true;
         webPage.cancelWork (ctx->bDialOut ? GVAW_dialOut : GVAW_dialCallback);
     }
-}//MainWindow::onDialDlgClose
+}//MainWindow::onSigDialComplete
 
 void
 MainWindow::dialInProgress (const QString & /*strNumber*/)
@@ -1642,7 +1644,7 @@ MainWindow::onSigProxyChanges(bool bEnable, bool bUseSystemProxy,
     {
         QObject *pRoot = this->rootObject ();
         if (NULL == pRoot) {
-            qWarning ("Could not get to root object in QML!!!");
+            qWarning ("Couldn't get root object in QML for ProxySettingsPage");
             break;
         }
 
@@ -1667,6 +1669,7 @@ MainWindow::onSigProxyChanges(bool bEnable, bool bUseSystemProxy,
 void
 MainWindow::onLinkActivated (const QString &strLink)
 {
+    qDebug() << "MainWindow: Link activated" << strLink;
     QDesktopServices::openUrl (QUrl::fromUserInput (strLink));
 }//MainWindow::onLinkActivated
 
@@ -1681,7 +1684,7 @@ MainWindow::onSigMosquittoChanges (bool bEnable, const QString &host, int port,
     {
         QObject *pRoot = this->rootObject ();
         if (NULL == pRoot) {
-            qWarning ("Could not get to root object in QML!!!");
+            qWarning ("Couldn't get root object in QML for MosquittoPage");
             break;
         }
 
